import React, { useState } from 'react';
import { X } from 'lucide-react';
import { addServer } from '../lib/db';

interface AddServerModalProps {
  onClose: () => void;
  onServerAdded: () => void;
}

export function AddServerModal({ onClose, onServerAdded }: AddServerModalProps) {
  const [formData, setFormData] = useState({
    name: '',
    model: '',
    cpu_model: '',
    ram_gb: '',
    influx_enabled: false,
    influx_org: '',
    influx_token: '',
    influx_url: ''
  });

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    
    try {
      await addServer({
        ...formData,
        ram_gb: parseInt(formData.ram_gb)
      });
      onServerAdded();
      onClose();
    } catch (error) {
      console.error('Failed to add server:', error);
      alert('Failed to add server. Please try again.');
    }
  };

  return (
    <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center">
      <div className="bg-gray-800 p-6 rounded-lg w-full max-w-md">
        <div className="flex justify-between items-center mb-4">
          <h2 className="text-xl font-semibold text-white">Add New Server</h2>
          <button onClick={onClose} className="text-gray-400 hover:text-white">
            <X size={24} />
          </button>
        </div>
        
        <form onSubmit={handleSubmit} className="space-y-4">
          <div>
            <label className="block text-sm font-medium text-gray-300">Server Name</label>
            <input
              type="text"
              className="mt-1 block w-full rounded-md bg-gray-700 border-gray-600 text-white"
              value={formData.name}
              onChange={(e) => setFormData({ ...formData, name: e.target.value })}
              required
            />
          </div>
          
          <div>
            <label className="block text-sm font-medium text-gray-300">Server Model</label>
            <input
              type="text"
              placeholder="e.g. Dell R730"
              className="mt-1 block w-full rounded-md bg-gray-700 border-gray-600 text-white"
              value={formData.model}
              onChange={(e) => setFormData({ ...formData, model: e.target.value })}
              required
            />
          </div>
          
          <div>
            <label className="block text-sm font-medium text-gray-300">CPU Model</label>
            <input
              type="text"
              placeholder="e.g. Intel Xeon E5-2680 v3"
              className="mt-1 block w-full rounded-md bg-gray-700 border-gray-600 text-white"
              value={formData.cpu_model}
              onChange={(e) => setFormData({ ...formData, cpu_model: e.target.value })}
              required
            />
          </div>
          
          <div>
            <label className="block text-sm font-medium text-gray-300">RAM (GB)</label>
            <input
              type="number"
              className="mt-1 block w-full rounded-md bg-gray-700 border-gray-600 text-white"
              value={formData.ram_gb}
              onChange={(e) => setFormData({ ...formData, ram_gb: e.target.value })}
              required
            />
          </div>

          <div className="flex items-center space-x-2">
            <input
              type="checkbox"
              id="influxEnabled"
              className="rounded bg-gray-700 border-gray-600 text-blue-600"
              checked={formData.influx_enabled}
              onChange={(e) => setFormData({ ...formData, influx_enabled: e.target.checked })}
            />
            <label htmlFor="influxEnabled" className="text-sm font-medium text-gray-300">
              Enable InfluxDB Metrics
            </label>
          </div>
          
          {formData.influx_enabled && (
            <>
              <div>
                <label className="block text-sm font-medium text-gray-300">InfluxDB Organization</label>
                <input
                  type="text"
                  className="mt-1 block w-full rounded-md bg-gray-700 border-gray-600 text-white"
                  value={formData.influx_org}
                  onChange={(e) => setFormData({ ...formData, influx_org: e.target.value })}
                  required={formData.influx_enabled}
                />
              </div>
              
              <div>
                <label className="block text-sm font-medium text-gray-300">InfluxDB Token</label>
                <input
                  type="password"
                  className="mt-1 block w-full rounded-md bg-gray-700 border-gray-600 text-white"
                  value={formData.influx_token}
                  onChange={(e) => setFormData({ ...formData, influx_token: e.target.value })}
                  required={formData.influx_enabled}
                />
              </div>
              
              <div>
                <label className="block text-sm font-medium text-gray-300">InfluxDB URL</label>
                <input
                  type="url"
                  className="mt-1 block w-full rounded-md bg-gray-700 border-gray-600 text-white"
                  value={formData.influx_url}
                  onChange={(e) => setFormData({ ...formData, influx_url: e.target.value })}
                  required={formData.influx_enabled}
                />
              </div>
            </>
          )}
          
          <button
            type="submit"
            className="w-full bg-blue-600 text-white rounded-md py-2 hover:bg-blue-700 transition-colors"
          >
            Add Server
          </button>
        </form>
      </div>
    </div>
  );
}